"""
Service Matrix Endpoints
=========================

These endpoints are intended for getting service matrix.

.. contents:: :local:

/service-matrix
---------------------

.. autofunction:: compendium_v2.routes.service_matrix

"""
import json
import logging
import os

from flask import Blueprint

from compendium_v2.routes import common

SERVICE_MATRIX_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',
    'type': 'object',
    'properties': {
        'key': {
            'type': 'string'
        },
        'nrens': {
            'type': 'array',
            'items': {
                'type': 'object',
                'properties': {
                    'name': {
                        'type': 'string'
                    },
                    'nren_id': {
                        'type': 'integer'
                    },
                    'tags': {
                        'type': 'array',
                        'items': {}
                    }
                },
                'required': [
                    'name',
                    'nren_id',
                    'tags'
                ],
                'additionalProperties': True
            }
        }
    }
}

DUMMY_DATA_FILENAME = os.path.abspath(os.path.join(
    os.path.dirname(__file__),
    '..',
    'datasources',
    'dummy-service-matrix.json'
))
routes = Blueprint('compendium-v2-service-matrix', __name__)
logger = logging.getLogger(__name__)

file_name = open(DUMMY_DATA_FILENAME)

service_matrix_response = json.loads(file_name.read())


@routes.route('', methods=['GET'])
@common.require_accepts_json
def get_service_matrix():
    """
    handler for /service-matrix requests

    response will be formatted as:

    .. asjson::
        compendium_v2.routes.api.THING_LIST_SCHEMA

    :return:
    """
    return service_matrix_response
