import json
import os
import tempfile

import pytest
import compendium_v2
from compendium_v2 import db
from compendium_v2.db import model
from compendium_v2.survey_db import model as survey_model

from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from sqlalchemy.pool import StaticPool


@pytest.fixture
def dummy_config():
    yield {
        'SQLALCHEMY_DATABASE_URI': 'sqlite://',
        'SURVEY_DATABASE_URI': 'sqlite:///'
    }


@pytest.fixture
def mocked_survey_db(mocker):
    engine = create_engine(
        'sqlite://',
        connect_args={'check_same_thread': False},
        poolclass=StaticPool,
        echo=False)
    survey_model.base_schema.metadata.create_all(engine)
    mocker.patch(
        'compendium_v2.survey_db._SESSION_MAKER',
        sessionmaker(bind=engine))
    mocker.patch(
        'compendium_v2.survey_db.init_db_model',
        lambda dsn: None)


@pytest.fixture
def mocked_db(mocker):
    # cf. https://stackoverflow.com/a/33057675
    engine = create_engine(
        'sqlite://',
        connect_args={'check_same_thread': False},
        poolclass=StaticPool,
        echo=False)
    model.base_schema.metadata.create_all(engine)
    mocker.patch(
        'compendium_v2.db._SESSION_MAKER',
        sessionmaker(bind=engine))
    mocker.patch(
        'compendium_v2.db.init_db_model',
        lambda dsn: None)
    mocker.patch(
        'compendium_v2.migrate_database',
        lambda config: None)


@pytest.fixture
def create_test_presentation_data():
    with db.session_scope() as session:
        session.add(
            model.BudgetEntry(
                id=1,
                nren='testnren',
                budget=123,
                year=2023,)
        )


@pytest.fixture
def data_config_filename(dummy_config):
    with tempfile.NamedTemporaryFile() as f:
        f.write(json.dumps(dummy_config).encode('utf-8'))
        f.flush()
        yield f.name


@pytest.fixture
def client(data_config_filename, mocked_db, mocked_survey_db):
    os.environ['SETTINGS_FILENAME'] = data_config_filename
    with compendium_v2.create_app().test_client() as c:
        yield c
