import json

import jsonschema
import pytest

from compendium_v2.routes.budget import BUDGET_RESPONSE_SCHEMA
from compendium_v2.routes.default import VERSION_SCHEMA


@pytest.mark.parametrize(
    'endpoint',
    ['version'])
def test_bad_accept(endpoint, client):
    rv = client.post(
        endpoint,
        headers={'Accept': ['text/html']})
    assert rv.status_code == 406


def test_version_request(client):
    rv = client.post(
        'version',
        headers={'Accept': ['application/json']})
    assert rv.status_code == 200
    result = json.loads(rv.data.decode('utf-8'))
    jsonschema.validate(result, VERSION_SCHEMA)


def test_budget_response(client, create_test_presentation_data):
    rv = client.get(
        '/api/budget/',
        headers={'Accept': ['application/json']})
    assert rv.status_code == 200
    result = json.loads(rv.data.decode('utf-8'))
    jsonschema.validate(result, BUDGET_RESPONSE_SCHEMA)
